@@ -4,7 +4,7 @@ use strict;
 use DateTime;
 use DateTime::Set;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 sub FirstMonday {
     my ($year, $month) = (shift, shift);
@@ -101,6 +101,28 @@ sub SearchDefaultCalendar {
     }
 }
 
+package RT::Interface::Web::Menu;
+
+# we should get an add_after method in 4.0.5, but until then
+# shim this in so I don't copy the code.
+unless (RT::Interface::Web::Menu->can('add_after')) {
+        *RT::Interface::Web::Menu::add_after = sub {
+            my $self = shift;
+            my $parent = $self->parent;
+            my $sort_order;
+            for my $contemporary ($parent->children) {
+                if ( $contemporary->key eq $self->key ) {
+                    $sort_order = $contemporary->sort_order + 1;
+                    next;
+                }
+                if ( $sort_order ) {
+                    $contemporary->sort_order( $contemporary->sort_order + 1 );
+                }
+            }
+            $parent->child( @_, sort_order => $sort_order );
+        };
+}
+
 
 1;
 
@@ -110,10 +132,6 @@ __END__
 
 RTx::Calendar - Calendar for RT due tasks
 
-=head1 VERSION
-
-This document describes version 0.07 of RTx::Calendar
-
 =head1 DESCRIPTION
 
 This RT extension provides a calendar view for your tickets and your
